﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Imaging;
using System.Diagnostics;
using System.Runtime.InteropServices;
using Microsoft.VisualBasic;

namespace USBPanicButton
{
    public static class Actions
    {
        [DllImport("user32.dll")]
        static extern bool SetForegroundWindow(IntPtr hWnd);
        
        [System.Runtime.InteropServices.DllImport("winmm.DLL", EntryPoint = "PlaySound", SetLastError = true)]
        private static extern bool PlaySound(string szSound, System.IntPtr hMod, PlaySoundFlags flags);

        [System.Flags]
        private enum PlaySoundFlags : int
        {
            SND_SYNC = 0x0000,
            SND_ASYNC = 0x0001,
            SND_NODEFAULT = 0x0002,
            SND_LOOP = 0x0008,
            SND_NOSTOP = 0x0010,
            SND_NOWAIT = 0x00002000,
            SND_FILENAME = 0x00020000,
            SND_RESOURCE = 0x00040004
        }

        public static void PlaySound(string strFile)
        {
            PlaySound(strFile, new System.IntPtr(), PlaySoundFlags.SND_ASYNC);
        }

        private static Bitmap bmpScreenshot;
        private static Graphics gfxScreenshot;
        public static void EarthQuake()
        {
            try
            {
                // Set the bitmap object to the size of the screen
                bmpScreenshot = new Bitmap(Screen.PrimaryScreen.Bounds.Width, Screen.PrimaryScreen.Bounds.Height, PixelFormat.Format32bppArgb);

                // Create a graphics object from the bitmap
                gfxScreenshot = Graphics.FromImage(bmpScreenshot);

                // Take the screenshot from the upper left corner to the right bottom corner
                gfxScreenshot.CopyFromScreen(Screen.PrimaryScreen.Bounds.X, Screen.PrimaryScreen.Bounds.Y, 0, 0, Screen.PrimaryScreen.Bounds.Size, CopyPixelOperation.SourceCopy);

                // Make a Form with a PictureBox
                Form _form = new Form();
                _form.AutoSize = true;
                _form.WindowState = FormWindowState.Maximized;
                _form.FormBorderStyle = FormBorderStyle.None;
                _form.BackColor = Color.Black;
                _form.ShowInTaskbar = false;

                PictureBox _pictureBox = new PictureBox();
                _pictureBox.SizeMode = PictureBoxSizeMode.AutoSize;
                _pictureBox.Image = bmpScreenshot;
                _form.Controls.Add(_pictureBox);
                _form.TopMost = true;
                _form.Focus();
                _form.BringToFront();
                _form.Show();

                ShakeIt(_pictureBox);
                
                _form.Dispose();
            }
            catch (Exception ex)
            {
                DisplayException(ex.Source, ex);
            } 
        }

        public static void ShakeIt(PictureBox _pictureBox)
        {
            int x = 0;
            int y = 0;
            int orgx = _pictureBox.Left;
            int orgy = _pictureBox.Top;
            Random r = new Random();
            for (int i = 0; i < 50; i++)
            {                
                x = r.Next(-10, 10);
                y = r.Next(-10, 10);
                _pictureBox.Left = orgx + x; 
                _pictureBox.Top = orgy + y;
                Application.DoEvents();
            }            
        }

        public static void DoCommand(string strCommand)
        {
            try
            {
                if (!string.IsNullOrEmpty(strCommand.Trim()))
                {
                    System.Diagnostics.Process proc = new System.Diagnostics.Process();
                    proc.EnableRaisingEvents = false;
                    proc.StartInfo.FileName = strCommand;
                    proc.Start();
                }
            }
            catch (Exception ex)
            {
                DisplayException(ex.Source, ex);
            } 
        }

        public static void PowerPointNextSlide()
        {
            Process[] p;
            IntPtr powerPointHandle;

            try
            {
                p = Process.GetProcessesByName("powerpnt");
                powerPointHandle = p[0].MainWindowHandle;
                SetForegroundWindow(powerPointHandle);
                SendKeys.SendWait("{PGDN}");               
            }
            catch (Exception ex)
            {
                DisplayException(ex.Source, ex);
            }
            try
            {
                p = Process.GetProcessesByName("pptview");
                powerPointHandle = p[0].MainWindowHandle;
                SetForegroundWindow(powerPointHandle);
                SendKeys.SendWait("{PGDN}");
            }
            catch (Exception ex)
            {
                DisplayException(ex.Source, ex);
            } 
        }

        public static Form frmPicture;
        public static void ShowPicture(string p, bool blnShake)
        {
            Image _image = Image.FromFile(p);

            // Make a Form with a PictureBox
            frmPicture = new Form();
            frmPicture.AutoSize = true;
            frmPicture.WindowState = FormWindowState.Maximized;
            frmPicture.FormBorderStyle = FormBorderStyle.None;
            frmPicture.BackColor = Color.Black;
            frmPicture.ShowInTaskbar = false;
          
            PictureBox _pictureBox = new PictureBox();
            _pictureBox.SizeMode = PictureBoxSizeMode.StretchImage;
            _pictureBox.Width = Screen.PrimaryScreen.Bounds.Width;
            _pictureBox.Height = Screen.PrimaryScreen.Bounds.Height;
            _pictureBox.Image = _image;
            _pictureBox.Click += new EventHandler(_pictureBox_Click);
            frmPicture.Controls.Add(_pictureBox);
            frmPicture.TopMost = true;
            frmPicture.Focus();
            frmPicture.BringToFront();
            frmPicture.Show();

            if (blnShake) ShakeIt(_pictureBox);
        }

        static void _pictureBox_Click(object sender, EventArgs e)
        {
            frmPicture.Dispose();
            frmPicture = null;
        }

        private static void DisplayException(String moduleName, Exception e)
        {
            String message = null;
            String caption = null;

            //  Create an error message.
            message = "Exception: " + e.Message + ControlChars.CrLf + "Module: " + moduleName + ControlChars.CrLf + "Method: " + e.TargetSite.Name;
            Debug.Write(message);
        }
   }
}